@@ -78,6 +78,13 @@ def bioshed_cli_main( args ):
             else:
                 print('Must specify a cloud provider - e.g., bioshed setup aws')
         elif cmd == 'init':
+            # first create init directory if doesn't exist
+            if not os.path.exists(INIT_PATH):
+                os.mkdir(INIT_PATH)
+            # create config file if doesn't exist
+            if not os.path.exists(AWS_CONFIG_FILE):
+                with open(AWS_CONFIG_FILE,'w') as fout:
+                    fout.write('{}')
             # ask for login name (email)
             login_success = bioshed_init.bioshed_login()
             if login_success["login"]:
